import React, { useState } from 'react';
import { useDispatch } from 'react-redux';
import { FormCard, FormBody, FormTitle, FormHBar } from '../../../components/forms';
import { Input } from '@graphpolaris/shared/lib/components/inputs';

export const CypherQuerySearch = () => {
  const [cypherQuery, setCypherQuery] = useState('');
  const dispatch = useDispatch();

  const handleCypherQueryChange = (event: React.ChangeEvent<HTMLInputElement>) => {
    setCypherQuery(event.target.value);
  };

  const handleCypherQuerySubmit = async () => {
    try {
      const response = await fetch('http://localhost:8080/execute-cypher-query', {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
        },
        body: JSON.stringify({ query: cypherQuery }),
      });

      if (!response.ok) {
        throw new Error('Network response was not ok');
      }

      const result = await response.json();
      console.log('Query Result:', result);

    } catch (error) {
      console.error('Error executing Cypher query:', error);
    }
  };

  return (
    <div>
      <FormCard>
        <FormBody
          onSubmit={(e) => {
            e.preventDefault();
            handleCypherQuerySubmit();
          }}
        >
          <FormTitle title="Search Cypher Query" />
          <FormHBar />
          <div className="px-5">
            <Input
              type="text"
              value={cypherQuery}
              onChange={handleCypherQueryChange as any}
              placeholder="Enter Cypher query"
            />
          </div>
          <div className="flex justify-end gap-2 mt-4">
            <button
              type="button"
              onClick={() => {
                handleCypherQuerySubmit();
              }}
              className="btn btn-primary"
            >
              Apply
            </button>
            <button
              type="button"
              onClick={() => setCypherQuery('')}
              className="btn btn-secondary"
            >
              Cancel
            </button>
          </div>
        </FormBody>
      </FormCard>
    </div>
  );
};
